.. html::

    <div class="row">
      <a href="https://liberalarts.utexas.edu/imhr/">
          <img src="https://risoms.github.io/mdl/docs/source/_static/img/imhr-header.png" height="auto" width="100%" max-width="400px">
      </a>
    <div>

.. image:: https://img.shields.io/badge/DOI-10.1016%2Fj.cct.2018.10.014-blue.svg?style=flat-square
   :target: https://doi.org/10.1016/j.cct.2018.10.014
   :alt: doi

.. image:: https://img.shields.io/pypi/l/imhr.svg?style=flat-square
   :target: https://github.com/risoms/mdl/blob/master/LICENSE
   :alt: license

.. image:: https://img.shields.io/pypi/pyversions/imhr.svg?style=flat-square
   :target: https://pypi.org/project/imhr/
   :alt: python

.. image:: https://img.shields.io/pypi/v/imhr.svg?style=flat-square
   :target: https://pypi.org/project/imhr/
   :alt: version-pypi

.. image:: https://anaconda.org/risoms/imhr/badges/version.svg
   :target: https://anaconda.org/risoms/imhr
   :alt: version-anaconda

.. image:: https://img.shields.io/conda/pn/conda-forge/python.svg?style=flat-square
   :target: https://anaconda.org/risoms/imhr
   :alt: platform

.. image:: https://travis-ci.com/risoms/mdl.svg?style=flat-square&token=h4xHN6seBuC4SG7zNtMW&branch=master
   :target: https://travis-ci.com/risoms/mdl
   :alt: Build Status

.. markdown::

    mdl: an extensive suite for the exploration, visualization, and analysis of psychological data.
    -------------------------------------------------------------------------------------------------

    This library was created at [the Institute for Mental Health Research](http://mdl.psy.utexas.edu/), at [the University 
    of Texas at Austin](http://www.utexas.edu/) by [Semeon Risom](https://semeon.io). This library was developed in part by 
    funding of NIMH grant [5R33MH109600-03](https://projectreporter.nih.gov/project_info_details.cfm?aid=9659376).

      Hsu, K. J., Caffey, K., Pisner, D., Shumake, J., Risom, S., Ray, K. L., . . . Beevers, C. G. (2018). Attentional bias 
      modification treatment for depression: Study protocol for a randomized controlled trial. Contemporary Clinical Trials, 75, 59-66. doi:https://doi.org/10.1016/j.cct.2018.10.014.

    Documentation
    -------------

    Online documentation is available [here](https://risoms.github.io/mdl/docs/build/py-modindex.html). Documentation include 
    [examples](https://risoms.github.io/mdl/docs/build/examples/index.html), [API reference](https://risoms.github.io/mdl/docs/build/api/mdl.html), and other useful information.

    Dependencies
    ------------

    mdl requires the following dependencies:

    -  [Python 3.6+](https://www.python.org/downloads/)
    -  [numpy](http://www.numpy.org/)
    -  [scipy](https://www.scipy.org/)
    -  [Pillow](https://pillow.readthedocs.io/en/stable/index.html)
    -  [matplotlib](https://matplotlib.org)
    -  [pywin32 (Windows)](https://github.com/mhammond/pywin32)
    -  [pyobjc (Mac OS)](https://pythonhosted.org/pyobjc/)

    Installation
    ------------

    This package and its dependencies are available as wheel packages for macOS, Windows and Linux distributions from [PyPI](https://pypi.org/project/imhr):

      python -m pip install imhr

    or the [anaconda](https://anaconda.org/risoms/imhr) package cloud repo:

      conda install -c risoms imhr

    Alternatively, you can install the development version directly from [github](https://www.github.com/risoms/mdl):

      pip install git+https://github.com/risoms/mdl.git
